#
# spec file for package python-Routes
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-Routes
Version:        2.5.1
Release:        5.1
Summary:        Routing Recognition and Generation Tools
License:        BSD-3-Clause
URL:            https://routes.readthedocs.io/
Source:         https://files.pythonhosted.org/packages/source/R/Routes/Routes-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/bbangert/routes/pull/113 remove python2 support
Patch:          remove-six.patch
# for testing
BuildRequires:  %{python_module WebOb}
BuildRequires:  %{python_module WebTest}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module repoze.lru}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-repoze.lru >= 0.3
Provides:       python-routes = %{version}-%{release}
Obsoletes:      python-routes < %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
A Routing package for Python that matches URL's to dicts and vice versa.

%prep
%autosetup -p1 -n Routes-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest --doctest-modules routes

%files %{python_files}
%license LICENSE.txt
%doc CHANGELOG.rst README.rst
%{python_sitelib}/routes
%{python_sitelib}/[Rr]outes-%{version}.dist-info

%changelog
* Tue Jun 24 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
* Fri Jun  7 2024 Markéta Machová <mmachova@suse.com>
- Add remove-six.patch to get rid of six
* Thu Aug 18 2022 Ben Greiner <code@bnavigator.de>
- Clean specfile, remove coverage
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- add six dependency declaration
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.5.1:
  * Add compatibility for Python 3.7+.
  * Add graceful fallback for invalid character encoding from request object.
  * Enhanced performance for matching routes that share the same static prefix.
  * Fixed issue with child routes not passing route conditions to the Mapper.connect call.
  * Fixed documentation to reflect default value for minimization.
  * Allow backslash to escape special characters in route paths.
  * Resolve invalid escape sequences.
  * Remove support for Python 2.6, 3.3, and 3.4.
  * Remove obsolete Python 2.3 compat code.
* Wed Jun 17 2020 pgajdos@suse.com
- nose -> pytest
* Thu Nov  7 2019 Matej Cepl <mcepl@suse.com>
- Run through spec-cleaner
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Jun 29 2017 tbechtold@suse.com
- update to 2.4.1:
  * Release as a universal wheel. PR #75.
  * Convert readthedocs links for their .org -> .io migration for hosted projects.
- convert to singlespec
- Fix Source url
* Fri Jun  3 2016 tbechtold@suse.com
- update to 2.3.1:
  * Backwards compatability fix - connect should work with mandatory
    routename and optional path. Patch by Davanum Srinivas (PR #65).
  * Fix sub_domain equivalence check. Patch by Nikita Uvarov
  * Add support for protocol-relative URLs generation (i.e. starting with double
    slash ``//``). PR #60. Patch by Sviatoslav Sydorenko.
  * Add support for the ``middleware`` extra requirement, making possible to
    depend on ``webob`` optionally. PR #59. Patch by Sviatoslav Sydorenko.
  * Fix matching of an empty string route, which led to exception in earlier
    versions. PR #58. Patch by Sviatoslav Sydorenko.
  * Add support for the ``requirements`` option when using
    mapper.resource to create routes. PR #57. Patch by Sean Dague.
  * Concatenation fix when using submappers with path prefixes. Multiple
    submappers combined the path prefix inside the controller argument in
    non-obvious ways. The controller argument will now be properly carried
    through when using submappers. PR #28.
* Fri Aug  7 2015 hpj@urpla.net
- update to 2.2:
  * Fix Python 3 support. Patch by Victor Stinner.
- spell python-WebTest and python-WebOb correctly
* Mon Apr 20 2015 tbechtold@suse.com
- update to 2.1:
  * Fix 3 other route matching groups in route.py to use anonymous groups for
    optional sections to avoid exceeding regex limits. Fixes #15.
  * Printing a mapper now includes the Controller/action parameters from the
    route. Fixes #11.
  * Fix regression that didn't allow passing in params 'host', 'protocol', or
    'anchor'. They can now be passed in with a trailing '_' as was possible
    before commit d1d1742903fa5ca24ef848a6ae895303f2661b2a. Fixes #7.
  * URL generation with/without SCRIPT_NAME was resulting in the URL cache
    failing to return the appropriate cached URL generation. The URL cache
    should always include the SCRIPT_NAME, even if its empty, in the cache
    to avoid this, and now does. Fixes #6.
  * Extract Route creation into separate method in Mapper.  Subclasses of Route
    can be created by Mappers now.
  * Use the first X_FORWARDED_FOR value if there are multiple proxies in the
    path. Fixes #5.
  * Python 3.2/3.3 Support. Fixes Issue #2. Thanks to Alejandro Sánchez for
    the pull request!
- Enable testrun during build and adjust BuildRequires for that.
- Adjust documentation links.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Apr 16 2012 saschpe@suse.de
- Require python-repoze.lru
* Wed Mar 14 2012 saschpe@suse.de
- Update to version 1.13:
  * Fix bug with dots forcing extension by default. The portion with the dot
    can now be recognized. Patch by Michael Basnight.
- Simplified macro usage
* Tue Jan 24 2012 bwiedemann@suse.com
- Fix Obsoletes
* Thu Sep  1 2011 saschpe@suse.de
- Fix license to BSD-3-Clause (SPDX style)
* Thu Sep  1 2011 saschpe@suse.de
- Removed reStructuredText markup from description
* Thu Sep  1 2011 saschpe@suse.de
- Initial version
